@@ -998,14 +998,14 @@ class LbYumClient(object):
                 namematch = True
                 versionmatch = True
                 releasematch = True
-                if nameRegexp is not None and re.match(nameRegexp,
-                                                       pa.name) is None:
+                if nameRegexp is not None and re.search(nameRegexp,
+                                                        pa.name) is None:
                     namematch = False
-                if versionRegexp is not None and re.match(versionRegexp,
-                                                          pa.name) is None:
+                if versionRegexp is not None and re.search(versionRegexp,
+                                                           pa.name) is None:
                     versionmatch = False
-                if releaseRegexp is not None and re.match(releaseRegexp,
-                                                          pa.name) is None:
+                if releaseRegexp is not None and re.search(releaseRegexp,
+                                                           pa.name) is None:
                     releasematch = False
                 if namematch and versionmatch and releasematch:
                     yield pa
@@ -1026,14 +1026,14 @@ class LbYumClient(object):
                 namematch = True
                 versionmatch = True
                 releasematch = True
-                if nameRegexp is not None and re.match(nameRegexp,
-                                                       pa.name) is None:
+                if nameRegexp is not None and re.search(nameRegexp,
+                                                        pa.name) is None:
                     namematch = False
-                if versionRegexp is not None and re.match(versionRegexp,
-                                                          pa.name) is None:
+                if versionRegexp is not None and re.search(versionRegexp,
+                                                           pa.name) is None:
                     versionmatch = False
-                if releaseRegexp is not None and re.match(releaseRegexp,
-                                                          pa.name) is None:
+                if releaseRegexp is not None and re.search(releaseRegexp,
+                                                           pa.name) is None:
                     releasematch = False
                 if namematch and versionmatch and releasematch:
                     yield pa
