@@ -42,10 +42,12 @@ class Config:
         # Now adding the LHCb  URLs
         repos["lhcb"] = {"url": repourl + "/lhcb"}
         repos["lhcb2017"] = {"url": repourl + "/lhcb2017"}
+        repos["lhcb2018"] = {"url": repourl + "/lhcb2018"}
         repos["lcg"] = {
             "url": "http://lcgpackages.web.cern.ch/lcgpackages/rpms"}
         repos["lhcbext"] = {"url": repourl + "/lcg"}
         repos["lhcbincubator"] = {"url": repourl + "/incubator"}
+        repos["lcgbackup"] = {"url": repourl + "/lcgbackup"}
 
         self.repos = repos
 
